aboutsummaryrefslogtreecommitdiffstats
path: root/addressbook/contact-editor/test-editor.c
diff options
context:
space:
mode:
Diffstat (limited to 'addressbook/contact-editor/test-editor.c')
-rw-r--r--addressbook/contact-editor/test-editor.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/addressbook/contact-editor/test-editor.c b/addressbook/contact-editor/test-editor.c
index 22c871c693..4842a93bf2 100644
--- a/addressbook/contact-editor/test-editor.c
+++ b/addressbook/contact-editor/test-editor.c
@@ -1,8 +1,8 @@
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
* test-editor.c
* Copyright (C) 2000 Helix Code, Inc.
* Author: Chris Lahey <clahey@helixcode.com>
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License as
@@ -44,7 +44,7 @@
" \
"EMAIL;INTERNET:nat@nat.org
" \
-"EMAIL;INTERNET:nat@helixcode.com
+"EMAIL;INTERNET:nat@ximian.com
" \
"ADR;WORK;POSTAL:P.O. Box 101;;;Any Town;CA;91921-1234;
" \
@@ -103,7 +103,7 @@ static void about_callback( GtkWidget *widget, gpointer data )
GtkWidget *about =
gnome_about_new ( _( "Contact Editor Test" ), VERSION,
- _( "Copyright (C) 2000, Helix Code, Inc." ),
+ _( "Copyright (C) 2000, Ximian, Inc." ),
authors,
_( "This should test the contact editor canvas item" ),
NULL);
@@ -1,8 +1,8 @@
/*
* test-editor.c
- * Copyright (C) 2000 Helix Code, Inc.
- * Author: Chris Lahey <clahey@helixcode.com>
+ * Copyright (C) 2000 Ximian, Inc.
+ * Author: Chris Lahey <clahey@ximian.com>
*
* This library is free software; you can redistribute it and/or